@@ -41,9 +41,8 @@
 #' 
 #' @author Bryan A. Hanson, DePauw University.
 #' 
-#' @references \url{https://github.com/bryanhanson/ChemoSpec}
-#' 
 #' @keywords hplot
+#' @seealso Additional documentation at \url{https://bryanhanson.github.io/ChemoSpec/}
 #' 
 #' @examples
 #' 
@@ -64,6 +63,8 @@ baselineSpectra <- function(spectra, int = TRUE, retC = FALSE, ...) {
 	# "method" is not a formal argument for compatibility with baseline
 	# but we do need it if processing locally.
 	
+	.chkArgs(mode = 11L)
+	
 	dots <- list(...)
 	linear <- FALSE
 	if (any(names(dots) == "method")) {
