@@ -1,12 +1,10 @@
 #'
-#'
 #' Robust PCA of a Spectra Object
 #' 
 #' A wrapper which carries out robust PCA analysis on a \code{\link{Spectra}}
 #' object.  The data are row- and column-centered, and the user can select
 #' various options for scaling.
 #' 
-#' 
 #' @param spectra An object of S3 class \code{\link{Spectra}}.
 #'
 #' @param choice A character vector describing the type of scaling to be
@@ -19,6 +17,7 @@
 #'
 #' @seealso See \code{\link[pcaPP]{PCAgrid}} on which this function is based.
 #' For the classical version, see \code{\link{c_pcaSpectra}}.
+#' Additional documentation at \url{https://bryanhanson.github.io/ChemoSpec/}
 #' 
 #' For displaying the results, \code{\link{plotScree}}, 
 #' \code{\link{plotScores}}, \code{\link{plotLoadings}},
@@ -28,10 +27,10 @@
 #' @references K. Varmuza and P. Filzmoser \emph{Introduction to Multivariate
 #' Statistical Analysis in Chemometrics}, CRC Press, 2009.
 #' 
-#' \url{https://github.com/bryanhanson/ChemoSpec}\cr
-#'
 #' @author Bryan A. Hanson, DePauw University.
 #'
+#' @seealso \url{https://bryanhanson.github.io/ChemoSpec/}
+#'
 #' @keywords multivariate robust
 #'
 #' @examples
@@ -50,7 +49,7 @@ r_pcaSpectra <- function(spectra, choice = "noscale") {
 		stop("You need to install package pcaPP to use this function")
 	}
 	
-	if (missing(spectra)) stop("No spectral data set provided")
+	.chkArgs(mode = 11L)
 	chkSpectra(spectra)
 	
 	choices <- c("noscale", "mad") # trap for invalid scaling method
